@@ -8,7 +8,7 @@ from kafka.errors import KafkaError
 import threading
 import time
 import ssl
-
+from time import sleep
 
 class KNativeConsumer(threading.Thread):
     daemon = True    
@@ -65,6 +65,7 @@ class KNativeConsumer(threading.Thread):
         print("KafkaConsumer Instance Creation")
         try:                
             self.consumer=KafkaConsumer(
+                          topics=self.topics,
                           bootstrap_servers=bootstrap_server,   
                           group_id=group_id,     
                           security_protocol=self.security_protocol,
@@ -73,6 +74,7 @@ class KNativeConsumer(threading.Thread):
                           ssl_certfile=os.environ['KAFKA_NET_TLS_CERT'],
                           ssl_keyfile=os.environ['KAFKA_NET_TLS_KEY'],
                           api_version=(0,10),
+                          max_poll_records=2,
                           auto_offset_reset='earliest',
                           enable_auto_commit=False)
                          
@@ -103,16 +105,33 @@ class KNativeConsumer(threading.Thread):
         print("**** Print the Messages ****")
         
         try:
-            # self.consumer.subscribe([self.topics])
+            # (!?) wtf, why we need this to get partitions assigned
+            # AssertionError: No partitions are currently assigned if poll() is not called
+            self.consumer.poll()
+            self.consumer.seek_to_beginning()
+
+            # also AssertionError: No partitions are currently assigned if poll() is not called
+            print('partitions of the topic: ',self.consumer.partitions_for_topic(self.topics))
+            self.logger.error('partitions of the topic: ')
+            self.logger.error(self.consumer.partitions_for_topic(self.topics))
+            from kafka import TopicPartition
+            print('before poll() x2: ')
+            # print(self.consumer.position(TopicPartition(self.topics, 0)))
+            print(self.consumer.position(TopicPartition(self.topics, 2)))
+            self.logger.error(self.consumer.position(TopicPartition(self.topics, 2)))
+            # (!?) sometimes the first call to poll() returns nothing and doesnt change the offset
+            messages = self.consumer.poll()
+            sleep(1)
+            messages = self.consumer.poll()
+
+            print('after poll() x2: ')
+            #print(self.consumer.position(TopicPartition(self.topics, 0)))
+            print(self.consumer.position(TopicPartition(self.topics, 2)))
+            self.logger.error(self.consumer.position(TopicPartition(self.topics, 2)))
+            print('messages: ', messages)
+            self.logger.error(messages)
+
 
-            for message in self.consumer:
-                print("topic={} partition={} offset={} key={} value={}".format(message.topic,
-                                                                        message.partition,
-                                                                        message.offset,
-                                                                        message.key,
-                                                                        message.value))
-                print('consumed: {}'.format(message.value()))
-                self.logger.error('consumed: {}'.format(message.value()))
         except Exception as ex:
                 print("Inexception")
                 print("Exception while getting the message - {}".format(ex))
